start_server

Function start_server 

pub fn start_server(config: Config) -> Result<()>
Start the WarpDrive proxy server

This initializes a Pingora server with the WarpDrive proxy handler, configures HTTP listeners based on the config, and runs the server.

This function blocks forever (until a shutdown signal is received). Pingora creates its own runtime internally, so this must be called from a non-async context.

Errors

Returns an error if:

  • Server initialization fails
  • Port binding fails
  • Server runtime encounters an error